---
title: github collaborator
keywords: documentation
layout: documentation
sidebar: github_config_sidebar
toc: false
---
## Overview

Allows you to manage github collaborators on your repository. For
organization-owned repositories, the list of collaborators includes outside
collaborators, organization members with access through team memberships,
organization members with access through default organization permissions,
and organization owners.

Here is an example o how to do this:

    github_collaborator { 'authentication/owner/repo:collaborator':
      ensure      => 'present',
      permissions => 'pull',
    }

## Attributes



Attribute Name                                    | Short Description                                             |
------------------------------------------------- | ------------------------------------------------------------- |
[collaborator](#github_collaborator_collaborator) | The name of the collaborator.                                 |
[credentials](#github_collaborator_credentials)   | The credentials to use for github operations.                 |
[ensure](#github_collaborator_ensure)             | The basic property that the resource should be in.            |
[name](#github_collaborator_name)                 | The full name of the collaborator.                            |
[owner](#github_collaborator_owner)               | the owner of the repository.                                  |
[permissions](#github_collaborator_permissions)   |   The permissions the specified collaborator has on the repo. |
[provider](#github_collaborator_provider)         | resource.                                                     |
[repository](#github_collaborator_repository)     | The name of the repository.                                   |




### collaborator<a name='github_collaborator_collaborator'>

The name of the collaborator. This parameter is extracted from the full name.
No need to specify it in the body of the puppet type.


[Back to overview of github_collaborator](#attributes)


### credentials<a name='github_collaborator_credentials'>


The credentials to use for github operations. This parameter is extracted from the full name.
No need to specify it in the body of the puppet type.


This is the first part of the title of **all** github types

    github_repo { 'credentials/....':
      ...
    }

The credentials must first be specfied by using [github_credentials]()


[Back to overview of github_collaborator](#attributes)


### ensure<a name='github_collaborator_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of github_collaborator](#attributes)


### name<a name='github_collaborator_name'>

The full name of the collaborator. The full name of the hook consists of the

- autorisation
- owner
- repo name
- collaborator

Here is an example:

  github_collaborator { 'autorisation/owner/repo:collaborator':
      ...
    }

Puppet will map these values to the right puppet parameters.


[Back to overview of github_collaborator](#attributes)


### owner<a name='github_collaborator_owner'>

the owner of the repository. This parameter is extracted from the full name.
No need to specify it in the body of the puppet type.


[Back to overview of github_collaborator](#attributes)


### permissions<a name='github_collaborator_permissions'>

  The permissions the specified collaborator has on the repo.

github_collaborator { '...':
  ...
  permissions => 'pull',
  ...
}

Valid values are `admin`, `push`, `pull`. 
[Back to overview of github_collaborator](#attributes)


### provider<a name='github_collaborator_provider'>

The specific backend to use for this `github_collaborator`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage github repository collaborators through puppet


[Back to overview of github_collaborator](#attributes)


### repository<a name='github_collaborator_repository'>

The name of the repository. This parameter is extracted from the full name.
No need to specify it in the body of the puppet type.


[Back to overview of github_collaborator](#attributes)

