---
title: github organization
keywords: documentation
layout: documentation
sidebar: github_config_sidebar
toc: false
---
## Overview

Allows you to manage a github organization.

Here is an example on how to do this:

    github_organization { 'account/organization':
      ensure        => 'present',
      billing_email => 'billing@company.org',
      blog          => 'https://www.enterprisemodules.com',
      description   => 'A github organization',
      email         => 'info@company.org',
      location      => 'The Netherlands',
    }

## Attributes



Attribute Name                                      | Short Description                                    |
--------------------------------------------------- | ---------------------------------------------------- |
[billing_email](#github_organization_billing_email) | The email address to use for billing related issues. |
[blog](#github_organization_blog)                   | The url of a blog for the organization.              |
[company](#github_organization_company)             | Company name.                                        |
[credentials](#github_organization_credentials)     | The credentials to use for github operations.        |
[description](#github_organization_description)     | The description of the resource.                     |
[email](#github_organization_email)                 | Email address to use.                                |
[ensure](#github_organization_ensure)               | The basic property that the resource should be in.   |
[location](#github_organization_location)           | Location of the organization.                        |
[name](#github_organization_name)                   | The full name of the organization.                   |
[organization](#github_organization_organization)   | The name of the organization.                        |
[plan](#github_organization_plan)                   | The payment plan to use.                             |
[provider](#github_organization_provider)           | resource.                                            |




### billing_email<a name='github_organization_billing_email'>


The email address to use for billing related issues. Here is an example:

    github_organization { 'account/organization':
      ...
      billing_email => 'billing@company.org',
      ...
    }


[Back to overview of github_organization](#attributes)


### blog<a name='github_organization_blog'>


The url of a blog for the organization. Here is an example:

    github_organization { 'account/organization':
      ...
      blog          => 'https://www.enterprisemodules.com',
      ...
    }


[Back to overview of github_organization](#attributes)


### company<a name='github_organization_company'>


Company name. Here is an example:

    github_organization { 'account/organization':
      ...
      company => 'Company name',
      ...
    }


[Back to overview of github_organization](#attributes)


### credentials<a name='github_organization_credentials'>


The credentials to use for github operations. This parameter is extracted from the full name.
No need to specify it in the body of the puppet type.


This is the first part of the title of **all** github types

    github_repo { 'credentials/....':
      ...
    }

The credentials must first be specfied by using [github_credentials]()


[Back to overview of github_organization](#attributes)


### description<a name='github_organization_description'>


The description of the resource.

    github_... { '...':
      ...
      description => 'just some text',
      ...
    }


[Back to overview of github_organization](#attributes)


### email<a name='github_organization_email'>


Email address to use. Here is an example:

    github_organization { 'account/organization':
      ...
      email         => 'info@company.org',
      ...
    }


[Back to overview of github_organization](#attributes)


### ensure<a name='github_organization_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of github_organization](#attributes)


### location<a name='github_organization_location'>


Location of the organization. Here is an example:

    github_organization { 'account/organization':
      ...
      location      => 'The Netherlands',
      ...
    }


[Back to overview of github_organization](#attributes)


### name<a name='github_organization_name'>


The full name of the organization. The full name of the organization consists of the

- autorisation
- organization

Here is an example:

    github_organization { 'autorisation/organization':
      ...
    }

Puppet will map these values to the right puppet parameters.


[Back to overview of github_organization](#attributes)


### organization<a name='github_organization_organization'>

The name of the organization. This parameter is extracted from the full name.
No need to specify it in the body of the puppet type.


[Back to overview of github_organization](#attributes)


### plan<a name='github_organization_plan'>


The payment plan to use. Here is an example:

    github_organization { 'account/organization':
      ...
      plan =>
      ...
    }


[Back to overview of github_organization](#attributes)


### provider<a name='github_organization_provider'>

The specific backend to use for this `github_organization`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage github organizations through puppet


[Back to overview of github_organization](#attributes)

