---
title: github team
keywords: documentation
layout: documentation
sidebar: github_config_sidebar
toc: false
---
## Overview


Allows you to manage a github team. Here is an example on how to do this:

    github_team { 'authentication/organization/team_name':
      ensure      => 'present',
      description => 'My first team',
      members     => ['jim', 'spock', 'checkov']
      privacy     => 'secret',
    }

## Attributes



Attribute Name                            | Short Description                                               |
----------------------------------------- | --------------------------------------------------------------- |
[credentials](#github_team_credentials)   | The credentials to use for github operations.                   |
[description](#github_team_description)   | The description of the resource.                                |
[ensure](#github_team_ensure)             | The basic property that the resource should be in.              |
[id](#github_team_id)                     | For internal use only.                                          |
[members](#github_team_members)           | An array containing the login names of the members of the team. |
[name](#github_team_name)                 | The full name of the team.                                      |
[organization](#github_team_organization) | The name of the organization.                                   |
[privacy](#github_team_privacy)           | The level of privacy this team should have.                     |
[provider](#github_team_provider)         | resource.                                                       |
[team](#github_team_team)                 | The name of the team.                                           |




### credentials<a name='github_team_credentials'>


The credentials to use for github operations. This parameter is extracted from the full name.
No need to specify it in the body of the puppet type.


This is the first part of the title of **all** github types

    github_repo { 'credentials/....':
      ...
    }

The credentials must first be specfied by using [github_credentials]()


[Back to overview of github_team](#attributes)


### description<a name='github_team_description'>


The description of the resource.

    github_... { '...':
      ...
      description => 'just some text',
      ...
    }


[Back to overview of github_team](#attributes)


### ensure<a name='github_team_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of github_team](#attributes)


### id<a name='github_team_id'>

For internal use only. Don't use!


[Back to overview of github_team](#attributes)


### members<a name='github_team_members'>


An array containing the login names of the members of the team. Here is an example:

    github_team { '...':
      ...
      members     => ['jim', 'spock', 'checkov']
      ...
    }


[Back to overview of github_team](#attributes)


### name<a name='github_team_name'>

The full name of the team. The full name consists of the

- autorisation
- organization
- team name

Here is an example:

    github_team { 'authentication/organization/team_name':
      ...
    }

Puppet will map these values to the right puppet parameters.


[Back to overview of github_team](#attributes)


### organization<a name='github_team_organization'>

The name of the organization. This parameter is extracted from the full name.
No need to specify it in the body of the puppet type.


[Back to overview of github_team](#attributes)


### privacy<a name='github_team_privacy'>

The level of privacy this team should have. Can be one of:

* secret - only visible to organization owners and members of this team.
* closed - visible to all members of this organization.

Default: secret

    github_team { 'authentication/organization/team_name':
      ...
      privacy     => 'secret',
      ...
    }

Valid values are `secret`, `closed`. 
[Back to overview of github_team](#attributes)


### provider<a name='github_team_provider'>

The specific backend to use for this `github_team`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage github teams through puppet


[Back to overview of github_team](#attributes)


### team<a name='github_team_team'>

The name of the team. This parameter is extracted from the full name.
No need to specify it in the body of the puppet type.


[Back to overview of github_team](#attributes)

